Yuio By Example
===============

A simple step-by-step guide that will walk you through Yuio's essentials.

.. tip::

    All GIFs in this tutorial are generated automatically on documentation build.
    If you see anything strange, `open an issue`__!

    __ https://github.com/taminomara/yuio/issues

.. nice-toc::

    hello_world
        Basics of CLI apps and printing things to output.

    interactive_things
        Everything about ``yuio.io`` and Yuio's interactive capabilities.

    parsers
        Introduction to parsers and ``yuio.parse``.

    configs
        Working with configuration files.

    cli
        Exploring Yuio apps and CLI interfaces.

    themes
        Customizing Yuio's appearance.

    dbg
        Automated environment collection for bug reports.
